@@ -303,6 +303,7 @@
 #include <config.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <limits.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
@@ -987,9 +988,11 @@ flush_rle_buffer (job_options_t* job_options,
     xfer_t pixel_xfer = job_options->pixel_xfer;
     int bytes_per_line = job_options->bytes_per_line;
     switch (pixel_xfer) {
-    case RLE:
-      fwrite (rle_buffer, sizeof (char), rle_buffer_next - rle_buffer, stdout);
+    case RLE: {
+      size_t dummy
+        = fwrite (rle_buffer, sizeof (char), rle_buffer_next - rle_buffer, stdout);
       break;
+    }
     case ULP:
     case BIP: {
       unsigned char* p = rle_buffer;
@@ -1011,7 +1014,7 @@ flush_rle_buffer (job_options_t* job_options,
               emitted -= l; emitted++;
               for (; l <= 0; l++) putchar (data);
             } else { /* emit the l + 1 following bytes of data */
-              fwrite (p, sizeof (char), l + 1, stdout);
+              size_t dummy = fwrite (p, sizeof (char), l + 1, stdout);
               p += l; p++;
               linelen -= l; linelen--;
               emitted += l; emitted++;
